# video blur background

Convert vertical video to 16:9 horizontal video and make the excess background blur

## install

```sh
pip install bgblur
```

## How to use

```sh
bgblur -i "input video file path" -o "output video file path"
```
